@@ -1,19 +1,22 @@
 /* GNU m4 -- A simple macro processor
-   Copyright (C) 1989, 90, 91, 92, 93, 94 Free Software Foundation, Inc.
-  
+
+   Copyright (C) 1989, 1990, 1991, 1992, 1993, 1994, 2006
+   Free Software Foundation, Inc.
+
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-  
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-  
+
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+   02110-1301  USA
 */
 
 /* printf like formatting for m4.  */
@@ -222,14 +225,14 @@ format (struct obstack *obs, int argc, token_data **argv)
 	  width = ARG_INT (argc, argv);
 	  fmt++;
 	}
-      else if (isdigit (*fmt))
+      else if (isdigit (to_uchar (*fmt)))
 	{
 	  width = 0;
 	  do
 	    {
 	      width = width * 10 + *fmt++ - '0';
 	    }
-	  while (isdigit (*fmt));
+	  while (isdigit (to_uchar (*fmt)));
 	}
 
       /* Maximum precision.  */
@@ -241,14 +244,14 @@ format (struct obstack *obs, int argc, token_data **argv)
 	      prec = ARG_INT (argc, argv);
 	      ++fmt;
 	    }
-	  else if (isdigit (*fmt))
+	  else if (isdigit (to_uchar (*fmt)))
 	    {
 	      prec = 0;
 	      do
 		{
 		  prec = prec * 10 + *fmt++ - '0';
 		}
-	      while (isdigit (*fmt))
+	      while (isdigit (to_uchar (*fmt)))
 		;
 	    }
 	}
@@ -429,6 +432,12 @@ format (struct obstack *obs, int argc, token_data **argv)
 	    if (prec < 0)
 	      prec = 6;
 
+	    /* FIXME: For the following line, Dave Anglin reports
+	       ``warning: passing arg 1 of `clr0' discards `const' from
+	       pointer target type''.  I suspect fcvt might be declared
+	       as returning const on some systems.  Pouah!  I should
+	       revise this whole module, one of these days...  */
+
 	    t = clr0 (fcvt (val, min (prec, FCVTMAX), &decpt, &sgn));
 
 	    sign = sgn ? '-' : plus;
@@ -573,13 +582,13 @@ format (struct obstack *obs, int argc, token_data **argv)
 	  width = ARG_INT (argc, argv);
 	  fmt++;
 	}
-      else if (isdigit (*fmt))
+      else if (isdigit (to_uchar (*fmt)))
 	{
 	  do
 	    {
 	      fmt++;
 	    }
-	  while (isdigit (*fmt));
+	  while (isdigit (to_uchar (*fmt)));
 	}
 
       /* Maximum precision.  */
@@ -591,13 +600,13 @@ format (struct obstack *obs, int argc, token_data **argv)
 	      prec = ARG_INT (argc, argv);
 	      ++fmt;
 	    }
-	  else if (isdigit (*fmt))
+	  else if (isdigit (to_uchar (*fmt)))
 	    {
 	      do
 		{
 		  fmt++;
 		}
-	      while (isdigit (*fmt));
+	      while (isdigit (to_uchar (*fmt)));
 	    }
 	}
 
@@ -660,7 +669,7 @@ format (struct obstack *obs, int argc, token_data **argv)
       c = *fmt;
       *fmt = '\0';
 
-      switch(datatype) 
+      switch(datatype)
 	{
 	case INT:
 	  if (width != -1 && prec != -1)
