@@ -1,12 +1,12 @@
 /* GNU m4 -- A simple macro processor
 
-   Copyright (C) 1989, 1990, 1991, 1992, 1993, 1994, 2004, 2005 Free
+   Copyright (C) 1989, 1990, 1991, 1992, 1993, 1994, 2004, 2005, 2006 Free
    Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,7 +15,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+   02110-1301  USA
 */
 
 /* We use <config.h> instead of "config.h" so that a compilation
@@ -42,11 +43,8 @@
 # define voidstar char *
 #endif
 
-#ifdef PROTOTYPES
-# define _(Args) Args
-#else
-# define _(Args) ()
-#endif
+/* FIXME - we no longer need this ansi2knr hack.  */
+#define _(Args) Args
 
 #include <stdio.h>
 #include <ctype.h>
@@ -149,7 +147,7 @@ typedef struct token_data token_data;
 /* Option flags.  */
 extern int sync_output;			/* -s */
 extern int debug_level;			/* -d */
-extern int hash_table_size;		/* -H */
+extern size_t hash_table_size;		/* -H */
 extern int no_gnu_extensions;		/* -G */
 extern int prefix_all_builtins;		/* -P */
 extern int max_debug_argument_length;	/* -l */
@@ -298,12 +296,7 @@ struct token_data
 #endif
 	}
       u_t;
-      struct
-	{
-	  builtin_func *func;
-	  boolean traced;
-	}
-      u_f;
+      builtin_func *func;
     }
   u;
 };
@@ -313,8 +306,7 @@ struct token_data
 #ifdef ENABLE_CHANGEWORD
 # define TOKEN_DATA_ORIG_TEXT(Td)	((Td)->u.u_t.original_text)
 #endif
-#define TOKEN_DATA_FUNC(Td)		((Td)->u.u_f.func)
-#define TOKEN_DATA_FUNC_TRACED(Td) 	((Td)->u.u_f.traced)
+#define TOKEN_DATA_FUNC(Td)		((Td)->u.func)
 
 typedef enum token_type token_type;
 typedef enum token_data_type token_data_type;
@@ -326,7 +318,7 @@ void skip_line _((void));
 
 /* push back input */
 void push_file _((FILE *, const char *));
-void push_macro _((builtin_func *, boolean));
+void push_macro _((builtin_func *));
 struct obstack *push_string_init _((void));
 const char *push_string_finish _((void));
 void push_wrapup _((const char *));
@@ -378,10 +370,12 @@ enum symbol_lookup
 struct symbol
 {
   struct symbol *next;
-  boolean traced;
-  boolean shadowed;
-  boolean macro_args;
-  boolean blind_no_args;
+  boolean traced : 1;
+  boolean shadowed : 1;
+  boolean macro_args : 1;
+  boolean blind_no_args : 1;
+  boolean deleted : 1;
+  int pending_expansions;
 
   char *name;
   token_data data;
@@ -392,6 +386,8 @@ struct symbol
 #define SYMBOL_SHADOWED(S)	((S)->shadowed)
 #define SYMBOL_MACRO_ARGS(S)	((S)->macro_args)
 #define SYMBOL_BLIND_NO_ARGS(S)	((S)->blind_no_args)
+#define SYMBOL_DELETED(S)	((S)->deleted)
+#define SYMBOL_PENDING_EXPANSIONS(S) ((S)->pending_expansions)
 #define SYMBOL_NAME(S)		((S)->name)
 #define SYMBOL_TYPE(S)		(TOKEN_DATA_TYPE (&(S)->data))
 #define SYMBOL_TEXT(S)		(TOKEN_DATA_TEXT (&(S)->data))
@@ -405,6 +401,7 @@ typedef void hack_symbol ();
 
 extern symbol **symtab;
 
+void free_symbol _((symbol *sym));
 void symtab_init _((void));
 symbol *lookup_symbol _((const char *, symbol_lookup));
 void hack_all_symbols _((hack_symbol *, const char *));
@@ -419,9 +416,9 @@ void call_macro _((symbol *, int, token_data **, struct obstack *));
 struct builtin
 {
   const char *name;
-  boolean gnu_extension;
-  boolean groks_macro_args;
-  boolean blind_if_no_args;
+  boolean gnu_extension : 1;
+  boolean groks_macro_args : 1;
+  boolean blind_if_no_args : 1;
   builtin_func *func;
 };
 
@@ -436,7 +433,7 @@ typedef struct builtin builtin;
 typedef struct predefined predefined;
 
 void builtin_init _((void));
-void define_builtin _((const char *, const builtin *, symbol_lookup, boolean));
+void define_builtin _((const char *, const builtin *, symbol_lookup));
 void define_user_macro _((const char *, const char *, symbol_lookup));
 void undivert_all _((void));
 void expand_user_macro _((struct obstack *, symbol *, int, token_data **));
@@ -483,3 +480,8 @@ void reload_frozen_state _((const char *));
 # define DEBUG_SYM
 # define DEBUG_INCL
 #endif
+
+/* Convert a possibly-signed character to an unsigned character.  This is
+   a bit safer than casting to unsigned char, since it catches some type
+   errors that the cast doesn't.  */
+static inline unsigned char to_uchar (char ch) { return ch; }
