@@ -2,20 +2,21 @@
 
    Copyright (C) 1989, 1990, 1991, 1992, 1993, 1994, 2004, 2005 Free
    Software Foundation, Inc.
-  
+
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-  
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-  
+
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+   02110-1301  USA
 */
 
 #include "m4.h"
@@ -32,14 +33,14 @@
 
 /* Size of buffer size to use while copying files.  */
 #define COPY_BUFFER_SIZE (32 * 512)
- 
+
 #ifdef HAVE_TMPFILE
 extern FILE *tmpfile ();
 #endif
 
 /* Output functions.  Most of the complexity is for handling cpp like
    sync lines.
-  
+
    This code is fairly entangled with the code in input.c, and maybe it
    belongs there?  */
 
@@ -559,7 +560,7 @@ freeze_diversions (FILE *file)
   int divnum;
   struct diversion *diversion;
   struct stat file_stat;
-  
+
   saved_number = current_diversion;
   last_inserted = 0;
   make_diversion (0);
@@ -592,4 +593,3 @@ freeze_diversions (FILE *file)
   if (saved_number != last_inserted)
     fprintf (file, "D%d,0\n\n", saved_number);
 }
-
